import React from 'react'
import ReactDOM from 'react-dom/client'
import App from './App'
import './index.css'
import './styles/Loader.css'
import './styles/Transitions.css'
import VercelSpeedInsights from './components/VercelSpeedInsights'

// Add the import for our cache clearing utility
import { resetColumnCache } from './utils/clearCache'
// Clear cached column information on startup
resetColumnCache()
// Import reconnect utility for manual connection recovery
import './utils/reconnect'

// Type declaration for the React DevTools global hook
declare global {
  interface Window {
    __REACT_DEVTOOLS_GLOBAL_HOOK__?: {
      renderers?: Map<any, any>;
      supportsFiber?: boolean;
      inject?: (...args: any[]) => any;
      onScheduleFiberRoot?: (...args: any[]) => any;
      onCommitFiberRoot?: (...args: any[]) => any;
      onCommitFiberUnmount?: (...args: any[]) => any;
      injectIntoGlobalHook?: (...args: any[]) => any;
    };
  }
}

// Fix for React DevTools "Cannot read properties of undefined (reading 'forEach')" error
if (typeof window !== 'undefined' && !window.__REACT_DEVTOOLS_GLOBAL_HOOK__) {
  window.__REACT_DEVTOOLS_GLOBAL_HOOK__ = {
    renderers: new Map(),
    supportsFiber: true,
    inject: () => {},
    onCommitFiberRoot: () => {},
    onCommitFiberUnmount: () => {},
    onScheduleFiberRoot: () => {},
    injectIntoGlobalHook: () => {}
  };
}

// Add chunk loading retry logic
const MAX_RETRY_COUNT = 3;
const RETRY_DELAY = 1000; // 1 second

// Store module loading retry counts
const retryCountMap = new Map<string, number>();

// Custom error handler for module loading errors
const handleChunkLoadError = () => {
  console.error('Chunk loading failed!');
  const timestamp = Date.now();
  window.location.href = `${window.location.pathname}?reload=${timestamp}`;
  return false;
};

window.addEventListener('error', (event) => {
  if (event.message.includes('Loading chunk') && event.message.includes('failed')) {
    console.error('Chunk loading error detected, will try reloading');
    // Try to reload immediately
    const url = new URL(window.location.href);
    url.searchParams.set('reload', Date.now().toString());
    window.location.href = url.toString();
    
    // Prevent default error handling
    event.preventDefault();
  }
});

console.log('React application successfully mounted');

// Add Vercel Speed Insights in development mode
// It won't send any data in development but will help ensure it works properly
// in production
if (import.meta.env.DEV) {
  // Call the component instead of the function
  ReactDOM.createRoot(document.getElementById('root')!).render(
    <React.StrictMode>
      <App />
      <VercelSpeedInsights />
    </React.StrictMode>,
  )
} else {
  ReactDOM.createRoot(document.getElementById('root')!).render(
    <React.StrictMode>
      <App />
      <VercelSpeedInsights />
    </React.StrictMode>,
  )
} 